;**********************************************************************
; Mario J.P.F.G. Monteiro: July 2005 
; ESTA/CoRoT - Version 0.2
; IDL procedure to plot the Luminosity versus Effective Temperature
; for different evolutionary sequences.
;
; The parameter AGE determines which phase of evolution is represented.

.run open
.run skpcom

!p.multi=[1,1,1]  &  !y.style=1  &  !x.style=1
cs1=1.3  &  cs2= 1.0  &  cs3=0.6  &  !p.charsize=cs1
tv=3.0  &  !p.thick=tv  &  !p.charthick=tv  &  !x.thick=tv  &  !y.thick=tv

xl=4.39  &  xu=3.60  &  !x.range=[xl,xu]  &  dx=(xu-xl)/80.0
!x.title='!6Log T!deff!n'  &  !x.margin=[5.0,2.0]
yl=-0.8  &  yu=4.2  &  !y.range=[yl,yu]  &  dy=(yu-yl)/80.0
!y.title='!6Log L/L!d!9n!n!6'  &  !y.margin=[4.0,1.0]

window,xsize=800,ysize=600
plot,[0.0,0.0],[yl,yu],line=1

nt=2000  &  nd=7  &  xr=dblarr(nd,nt)  &  x=dblarr(nd,nt)

; This parameters selects the files to read: prems, ms, postms, all
age='all'

adir='./'  ; This the relative path for the directories with the files
am=['0.8','0.9',  $
    '1.0','1.1','1.2','1.3','1.4','1.5','1.6','1.8','1.9',  $
    '2.0','2.2','2.4','2.6','2.8', $
    '3.0','3.2','3.4','3.6','3.8',  $
    '4.0','4.5','5.0','5.5','6.0','6.5','7.0','7.5','8.0']
nmod=n_elements(am)

;--------------- S0 -----------------
nx=2  &  ny=1  & na=4
xagelim=1.0d0

xr=xu-0.02*(xu-xl)  &  yr=yu-0.06*(yu-yl)

nl=0
if (age eq 'postms') then nl=2
if (age eq 'prems') then nmod=23

for j=nl,nmod-1 do begin  & $
  afileloc=adir+am(j)+'0/hr_'+age+'.dat'  & $
  open,afileloc,nd,nt,x,n  & $
  ni=0 & nf=n-1  & $
;
  if (age eq 'all') then begin  & $
  oplot,x(nx,ni:nf),x(ny,ni:nf),line=0  & $
  xyouts,xr,yr,'!6[A] Full evolution',  $
    charsize=cs1,alignment=1.0  & $
  nlab=ni  & $
  end  & $
;
  if (age eq 'prems') then begin  & $
  id=where(x(4,ni:nf) gt  1.0)  & $
  oplot,x(nx,id),x(ny,id),line=1  & $
  xyouts,xr,yr,'!6[A] Pre-Main Sequence evolution',  $
    charsize=cs1,alignment=1.0  & $
  nlab=nf  & $
  end  & $
;
  if (age eq 'ms') then begin  & $
  oplot,x(nx,ni:nf),x(ny,ni:nf),line=0  & $
  xyouts,xr,yr,'!6[A] Main Sequence evolution',  $
    charsize=cs1,alignment=1.0  & $
  nlab=ni  & $
  end  & $
;
  if (age eq 'postms') then begin  & $
  oplot,x(nx,ni:nf),x(ny,ni:nf),line=2  & $
  xyouts,xr,yr,'!6[A] Post-Main Sequence evolution',  $
    charsize=cs1,alignment=1.0  & $
  nlab=ni  & $
  end  & $
;
  if (age ne 'all') then  $
    xyouts,x(nx,nlab)-dx,x(ny,nlab)-dy,am(j),charsize=cs2,  $
       alignment=1.0  & $
endfor

;----------------------------------------------------------------
